API Reference

Download Backends

BaseDownload

Abstract base class for all neuralfetch download backends.

Dandi

Download a Dandiset from the DANDI Archive (dandiarchive.org).

Eegdash

Download datasets from the EEGDash cloud archive.

Datalad

Download datasets via DataLad and git-annex.

Donders

Download datasets from the Donders Repository (data.donders.ru.nl).

Dryad

Download datasets from Dryad (datadryad.org).

Figshare

Download all files from a Figshare article (figshare.com).

Huggingface

Download a dataset repository from Hugging Face Hub.

Openneuro

Download datasets from OpenNeuro.

Osf

Download datasets from OSF (osf.io).

Physionet

Physionet datasets via anonymous boto3 access.

Synapse

Download datasets from Synapse.

Zenodo

Download datasets from Zenodo (zenodo.org).

Utilities

compute_study_info

Load study name from folder and return a dict of actual StudyInfo values.

update_source_info

Compute actual StudyInfo values, rewrite the source file, and run ruff format.

root_study_folder

Return the root folder where study data is stored.