API Reference¶
Download Backends¶
Abstract base class for all neuralfetch download backends. |
|
Download a Dandiset from the DANDI Archive (dandiarchive.org). |
|
Download datasets from the EEGDash cloud archive. |
|
Download datasets via DataLad and git-annex. |
|
Download datasets from the Donders Repository (data.donders.ru.nl). |
|
Download datasets from Dryad (datadryad.org). |
|
Download all files from a Figshare article (figshare.com). |
|
Download a dataset repository from Hugging Face Hub. |
|
Download datasets from OpenNeuro. |
|
Download datasets from OSF (osf.io). |
|
Physionet datasets via anonymous boto3 access. |
|
Download datasets from Synapse. |
|
Download datasets from Zenodo (zenodo.org). |
Utilities¶
Load study name from folder and return a dict of actual |
|
Compute actual |
|
Return the root folder where study data is stored. |